# bitwarden-import-msecure

Переход с mSecure на Bitwarden.

В отличие от встроенного инструмента импорта Bitwarden, этот скрипт не помещает каждый секрет в отдельную папку. 
Вместо этого он организует секреты в папки по смыслу и предлагает несколько опций для настройки процесса импорта.

Кроме того, этот простой скрипт на Python может быть легко изменен для удовлетворения ваших конкретных потребностей.

## Установка

## Установка pipx
[`pipx`](https://pypa.github.io/pipx/) создает изолированные среды, чтобы избежать конфликтов с 
существующими системными пакетами.

=== "MacOS"
    В терминале выполните:

    ```bash
    brew install pipx
    pipx ensurepath
    ```

=== "Linux"
    Сначала убедитесь, что Python установлен.

    Введите в терминал:

    ```bash
    python3 -m pip install --user pipx
    python3 -m pipx ensurepath
    ```

=== "Windows"
    Сначала установите Python, если он еще не установлен.

    В командной строке введите (если Python был установлен из Microsoft Store, используйте `python3` вместо `python`):
    
    ```bash
    python -m pip install --user pipx
    ```

## Установка `bitwarden-import-msecure`:
В терминале (командной строке) выполните:

```bash
pipx install bitwarden-import-msecure
```

## Использование

В mSecure выберите `File` -> `Export` -> `CSV..` и сохраните файл.

В терминале (командной строке) открытом в том же каталоге, что и экспортированный файл (или добавьте путь к каталогу):

```bash
bitwarden-import-msecure "mSecure Export File.csv"
```

Это создаст `bitwarden.json` в той же папке, что и исходный файл.

В диалоговом окне Bitwarden выберите `Файл` -> `Импорт данных`, выберите Формат файла: "Bitwarden (json)".
Выберите ранее созданный файл `bitwarden.json` и нажмите "Импорт данных".


### Дополнительно

Чтобы увидеть все параметры, используйте: 
```bash
bitwarden-import-msecure --help
```


